@@ -1,5 +1,6 @@
 import getpass
 import dataclasses
+import os
 from typing import Union
 
 
@@ -25,6 +26,10 @@ class GenericAdapter:
     def name(self) -> str:
         return "project"
 
+    @property
+    def registry(self) -> str:
+        return os.environ.get("DOCKER_REGISTRY", "docker.io")
+
     @property
     def organization(self) -> str:
         return getpass.getuser()
